From aea547cd11e4baa24cad12e13160e5ff2250a69f Mon Sep 17 00:00:00 2001
From: Justin Clark-Casey (justincc)
Date: Tue, 15 Nov 2011 23:24:51 +0000
Subject: fix build break on UserManagementModule.
This also adds time since started to "show threads". Unfortunately these two changes got mixed in.
---
OpenSim/Framework/Watchdog.cs | 11 +++++++----
1 file changed, 7 insertions(+), 4 deletions(-)
(limited to 'OpenSim/Framework/Watchdog.cs')
diff --git a/OpenSim/Framework/Watchdog.cs b/OpenSim/Framework/Watchdog.cs
index 0ee0c5b..2dd6ebe 100644
--- a/OpenSim/Framework/Watchdog.cs
+++ b/OpenSim/Framework/Watchdog.cs
@@ -52,10 +52,13 @@ namespace OpenSim.Framework
///
/// Approximate tick when this thread was started.
///
- public int StartTick { get; private set; }
+ ///
+ /// Not terribly good since this quickly wraps around.
+ ///
+ public int FirstTick { get; private set; }
///
/// Last time this heartbeat update was invoked
///
public int LastTick { get; set; }
@@ -73,8 +76,8 @@ namespace OpenSim.Framework
{
Thread = thread;
Timeout = timeout;
- StartTick = Environment.TickCount & Int32.MaxValue;
- LastTick = StartTick;
+ FirstTick = Environment.TickCount & Int32.MaxValue;
+ LastTick = FirstTick;
}
}
@@ -52,10 +52,13 @@ namespace OpenSim.Framework
///
- /// Last time this heartbeat update was invoked
+ /// First time this heartbeat update was invoked
///
public int LastTick { get; set; }
--
cgit v1.1